@@ -1,5 +1,5 @@
 package CMS::Drupal::Modules::MembershipEntity::Membership;
-$CMS::Drupal::Modules::MembershipEntity::Membership::VERSION = '0.095';
+$CMS::Drupal::Modules::MembershipEntity::Membership::VERSION = '0.90';
 # ABSTRACT: Perl interface to a Drupal MembershipEntity membership
 
 use strict;
@@ -17,12 +17,35 @@ has member_id => ( is => 'ro', isa => Str, required => 1 );
 has type      => ( is => 'ro', isa => Str, required => 1 );
 has terms     => ( is => 'ro', isa => HashRef, required => 1 );
 
+
+sub is_expired {
+  my $self = shift;
+  $self->{'_is_expired'} = $self->{'status'} eq '0' ? 1 : 0;
+  return $self->{'_is_expired'};
+}
+
+
 sub is_active {
   my $self = shift;
   $self->{'_is_active'} = $self->{'status'} eq '1' ? 1 : 0;
   return $self->{'_is_active'};
 }
 
+
+sub is_cancelled {
+  my $self = shift;
+  $self->{'_is_cancelled'} = $self->{'status'} eq '2' ? 1 : 0;
+  return $self->{'_is_cancelled'};
+}
+
+
+sub is_pending {
+  my $self = shift;
+  $self->{'_is_pending'} = $self->{'status'} eq '3' ? 1 : 0;
+  return $self->{'_is_pending'};
+}
+
+
 sub has_renewal {
   my $self = shift;
   $self->{'_has_renewal'} = 0;
@@ -33,6 +56,16 @@ sub has_renewal {
 }
 
 
+sub current_was_renewal {
+  my $self = shift;
+  $self->{'_current_was_renewal'} = 0;
+  foreach my $term ( values %{ $self->{'terms'} } ) {
+    $self->{'_current_was_renewal'}++ if ($term->is_current && $term->was_renewal);
+  }
+  return $self->{'_current_was_renewal'};
+}
+
+
 1; ## return true to end package MembershipEntity::Membership
 
 __END__
@@ -47,7 +80,7 @@ CMS::Drupal::Modules::MembershipEntity::Membership - Perl interface to a Drupal
 
 =head1 VERSION
 
-version 0.095
+version 0.90
 
 =head1 SYNOPSIS
 
@@ -66,11 +99,21 @@ version 0.095
 
 =head1 METHODS
 
+=head2 is_expired
+
+Returns 1 if the Membership has status of 'expired'. Else returns 0.
+
 =head2 is_active
 
-Returns 1 if the Membership is active, as defined by the value of the 'status' field in the database record. Else returns 0.
+Returns 1 if the Membership has status of 'active'. Else returns 0.
 
-  print "User $mem->{'uid'} is in good standing" if $mem->is_active;
+=head2 is_cancelled
+
+Returns 1 if the Membership has status of 'cancelled'. Else returns 0.
+
+=head2 is_pending
+
+Returns 1 if the Membership has status of 'pending'. Else returns 0.
 
 =head2 has_renewal
 
@@ -78,6 +121,11 @@ Returns 1 if the Membership has a renewal Term that has not yet started. This is
 
   print "User $mem->{'uid'} has already renewed" if $mem->has_renewal;
 
+=head2 current_was_renewal
+
+Returns 1 if the current Term belonging to the Membership was a renewal
+(i.e. not the Membership's first ever Term). Else returns 0.
+
 =head1 USAGE
 
 Note: This module does not currently create or edit Memberships.
